@@ -194,16 +194,6 @@ public class WebdavPrincipalServlet extends OXServlet {
         return true;
     }
 
-    @Override
-    protected void decrementRequests() {
-        // Nothing to do
-    }
-
-    @Override
-    protected void incrementRequests() {
-        // Nothing to do
-    }
-
     private static final LoginCustomizer ALLOW_ASTERISK = new AllowAsteriskAsSeparatorCustomizer();
 
     @Override
